@@ -1,13 +1,8 @@
 from enum import Enum
-from typing import TYPE_CHECKING, Any, cast
+from typing import Any, cast
 
 from starlite.exceptions import ImproperlyConfiguredException
 
-if TYPE_CHECKING:  # pragma: no cover
-    from starlite.types import Method
-else:
-    Method = Any
-
 
 class HttpMethod(str, Enum):
     GET = "get"
@@ -29,10 +24,6 @@ class HttpMethod(str, Enum):
             return cast(HttpMethod, value.lower())
         raise ImproperlyConfiguredException(f"value {value} is not a supported http method")
 
-    def to_str(self) -> "Method":
-        """Returns the string value as an upper cased string: get -> GET"""
-        return cast(Method, self.value.upper())
-
 
 class MediaType(str, Enum):
     JSON = "application/json"
