@@ -1,7 +1,11 @@
 # flake8: noqa
 from .model import convert_dataclass_to_model, create_parsed_model_field
 from .sequence import find_index, unique
-from .signature import SignatureModel, create_function_signature_model
+from .signature import (
+    SignatureModel,
+    create_function_signature_model,
+    get_signature_model,
+)
 from .url import join_paths, normalize_path
 
 __all__ = [
@@ -10,6 +14,7 @@ __all__ = [
     "create_function_signature_model",
     "create_parsed_model_field",
     "find_index",
+    "get_signature_model",
     "join_paths",
     "normalize_path",
     "unique",
